def recurring_fibonacci_number(number: int) -> int:
    if number < 0:
        raise ValueError("Fibonacci has to be equal or above zero")
    elif number <= 1:
        return number
    else:
        return recurring_fibonacci_number(number - 1) + \
            recurring_fibonacci_number(number - 2)


from unittest import main, TestCase
from unittest.mock import patch

from sibarras_fib_py.fib_calcs.fib_numbers import calculate_numbers

class Test(TestCase):
    
    @patch("sibarras_fib_py.fib_calcs.fib_numbers.recurring_fibonacci_number")
    def test_calculate_numbers(self, mock_fib_calc):
        expected_outcome = [mock_fib_calc.return_value, mock_fib_calc.return_value]
        self.assertEqual(expected_outcome, calculate_numbers(numbers=[3, 4]))
        self.assertEqual(2, len(mock_fib_calc.call_args_list))
        self.assertEqual({'number': 3}, mock_fib_calc.call_args_list[0][1])
        self.assertEqual({'number': 4}, mock_fib_calc.call_args_list[1][1])
    
    def test_functional(self):
        self.assertEqual([2, 3, 5],
            calculate_numbers(numbers=[3, 4, 5]))

if __name__ == "__main__":
    main()


import argparse

from sibarras_fib_py.fib_calcs.fib_number import recurring_fibonacci_number

def fib_numb() -> None:
    parser = argparse.ArgumentParser(
        description='Calculate Fibonacci Numbers')
    
    parser.add_argument(
        '--number',
        action='store',
        type=int,
        required=True,
        help="Fibonacci number to be calculated"
        )
    
    args = parser.parse_args()
    print("Your Fibonacci number is: "
        f"{recurring_fibonacci_number(number=args.number)}"
        )


from setuptools import find_packages, setup
from pathlib import Path

with open("README.md", 'r') as rme:
    long_description = rme.read()

with open("./sibarras_fib_py/version.py", 'rt') as vr:
    version = vr.read().split("=")[1].replace("'", "")

setup(
    name="sibarras_fib_py",
    version=version,
    author="Samuel Ibarra",
    author_email="ing.samuelibarra@gmail.com",
    description="Calculates a fibonacci number",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sibarras/sibarras-fib-py.git",
    install_requires=[
        "PyYAML>=4.1.2",
        "dill>=0.2.8"
    ],
    extras_require={
        'server': ["Flask>=1.0.0"]
    },
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
    test_require=['pytest'],
    entry_points={
        'console_scripts': [
            'fib-number = sibarras_fib_py.cmd.fib_numb:fib_numb', 
        ]
    }
)


from unittest import main, TestCase

from sibarras_fib_py.fib_calcs.fib_number import recurring_fibonacci_number

class RecurringFibNumberTest(TestCase):
    def test_zero(self):
        self.assertEqual(0, recurring_fibonacci_number(number=0))
    
    def test_negative(self):
        with self.assertRaises(ValueError) as raised_error:
            recurring_fibonacci_number(number=-1)
            self.assertEqual(
                "Fibonacci has to be equal or above zero",
                str(raised_error.exception)
            )

    def test_one(self):
        self.assertEqual(1, recurring_fibonacci_number(number=1))

    def test_two(self):
        self.assertEqual(1, recurring_fibonacci_number(number=2))

    def test_twenty(self):
        self.assertEqual(6765, recurring_fibonacci_number(number=20))

if __name__ == "__main__":
    main()
